@@ -413,11 +413,11 @@ Net::CalDAVTalk - Module to talk CalDAV and give a JSON interface to the data
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =cut
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 
 =head1 SYNOPSIS
@@ -701,6 +701,14 @@ sub GetCalendars {
         $Privileges{'mayReadFreeBusy'} = $JSON::true if $item->{"{$NS_C}read-free-busy"};
       }
 
+      my $CanSync;
+      my $Report = $Propstat->{"{$NS_D}prop"}{"{$NS_D}supported-report-set"}{"{$NS_D}supported-report"};
+      $Report = [] unless ($Report and ref($Report) eq 'ARRAY');
+      foreach my $item (@$Report) {
+        # XXX - do we want to check the other things too?
+        $CanSync = 1 if $item->{"{$NS_D}report"}{"{$NS_D}sync-collection"};
+      }
+
       my $CanEvent;
       my $Type = $Propstat->{"{$NS_D}prop"}{"{$NS_C}supported-calendar-data"}{"{$NS_C}calendar-data"};
       $Type = [] unless ($Type and ref($Type) eq 'ARRAY');
@@ -752,6 +760,7 @@ sub GetCalendars {
         precedence => int($Propstat->{"{$NS_D}prop"}{"{$NS_A}calendar-order"}{content} || 1),
         syncToken  => ($Propstat->{"{$NS_D}prop"}{"{$NS_D}sync-token"}{content} || ''),
         shareWith  => (@ShareWith ? \@ShareWith : $JSON::false),
+        canSync    => ($CanSync ? $JSON::true : $JSON::false),
         _can_event => ($CanEvent ? $JSON::true : $JSON::false),
         %Privileges,
       );
@@ -1229,7 +1238,6 @@ sub GetFreeBusy {
     }
   }
 
-  warn Dumper(\@result);
   return (\@result, \@errors);
 }
 
@@ -1261,6 +1269,27 @@ sub SyncEvents {
   return wantarray ? ($Events, $Removed, $Errors, $SyncToken, $Links) : $Events;
 }
 
+=head2 $self->SyncEventLinks($calendarId, %Args)
+
+Like GetEventLinks, but if you pass a syncToken argument, then it will
+fetch changes since that token (obtained from an earlier GetCalendars
+or SyncEvent* call).
+
+In scalar context still just returns Added, in list context returns
+Added, Removed, Errors and new token:
+
+* Added: hash of href to etag - added or changed
+* Removed: array of href
+* Errors: array of descritive string
+* NewToken: scalar opaque DAV:sync-token
+
+e.g.
+
+   my ($Added, $Removed, $Errors, $NewToken)
+      = $CalDAV->SyncEventLinks('Default', syncToken => '...');
+
+=cut
+
 sub SyncEventLinks {
   my ($Self, $calendarId, %Args) = @_;
 
@@ -1884,7 +1913,6 @@ sub _getEventsFromVCalendar {
           $Recurrence{frequency} = $freq;
         }
         else {
-          use Data::Dumper;
           confess "$uid: Recurrence FREQ not specified";
         }
 
